@@ -297,17 +297,39 @@ class Definition:
 					return
 				else:
 					raise Config.exception_factory.create_input_error(field_fqn, 'Not nullable.')
+			results[field_name] = value
+			Index._eval_data_type_rules(
+					results,
+					field_fqn,
+					field_name,
+					self,
+					**rules_kw
+				)
+			Index._eval_data_format_rules(
+					results,
+					field_fqn,
+					field_name,
+					self,
+					**rules_kw
+				)
 			if dependent_definition_name is not None:
 				Index.validate_input(
 						results,
 						field_fqn,
 						field_name,
 						dependent_definition_name,
-						value,
+						results[field_name],
 						dependent_values
 					)
 			else:
-				self.validator(results, field_fqn, field_name, self, value, dependent_values)
+				self.validator(
+						results,
+						field_fqn,
+						field_name,
+						self,
+						results[field_name],
+						dependent_values
+					)
 			for rule in self.rules:
 				results[field_name] = rule.execute(field_fqn, results[field_name], **rules_kw)
 			return results
@@ -330,6 +352,12 @@ class Definition:
 	def get_name(self):
 		return self.name
 
+	def get_data_type(self):
+		return self.data_type
+
+	def get_data_format(self):
+		return self.data_format
+
 	def get_description(self, delim=' ', cat_rules=False):
 		result = self.description
 		if cat_rules is True:
@@ -526,6 +554,10 @@ class DefinitionJsonDeserializer:
 
 class Index:
 	_idx = {}
+	_data_type_rules = {}
+	_data_type_rule_exceptions = set()
+	_data_format_rules = {}
+	_data_format_rule_exceptions = set()
 
 	def get(definition_or_name):
 		if isinstance(definition_or_name, Definition):
@@ -609,6 +641,46 @@ class Index:
 			Index._idx[entry] = definition
 		return definition
 
+	def register_data_type_rule(data_type, rule, exceptions=[]):
+		if data_type not in Index._data_type_rules:
+			Index._data_type_rules[data_type] = []
+		Index._data_type_rules[data_type].append(rule)
+		Index._data_type_rule_exceptions.update(exceptions)
+
+	def register_data_format_rule(data_format, rule, exceptions=[]):
+		if data_format not in Index._data_format_rules:
+			Index._data_format_rules[data_format] = []
+		Index._data_format_rules[data_format].append(rule)
+		Index._data_format_rule_exceptions.update(exceptions)
+
+	def _eval_data_type_rules(
+				results,
+				field_fqn,
+				field_name,
+				definition,
+				**rules_kw
+			):
+		if definition.get_data_type() not in Index._data_type_rules:
+			return
+		if definition.get_name() in Index._data_type_rule_exceptions:
+			return
+		for rule in Index._data_type_rules[definition.get_data_type()]:
+			results[field_name] = rule.execute(field_fqn, results[field_name], **rules_kw)
+
+	def _eval_data_format_rules(
+				results,
+				field_fqn,
+				field_name,
+				definition,
+				**rules_kw
+			):
+		if definition.get_data_format() not in Index._data_format_rules:
+			return
+		if definition.get_name() in Index._data_format_rule_exceptions:
+			return
+		for rule in Index._data_format_rules[definition.get_data_format()]:
+			results[field_name] = rule.execute(field_fqn, results[field_name], **rules_kw)
+
 	def validate_input(
 				validated,
 				field_fqn,
