@@ -15,5 +15,9 @@ class Index(dict):
 	def ensure(index):
 		if index is None:
 			return Index()
-		return index
-
+		if isinstance(index, dict):
+			return index
+		raise Config.exception_factory.create_input_error(
+				'ParameterIndex',
+				'Invalid index input type {0}.'.format(type(index))
+			)
\ No newline at end of file
