@@ -1,11 +1,6 @@
 from enum import unique, Enum
 
 
-@unique
-class SchemaOutputTarget(Enum):
-	Self = 1
-	Parent = 2
-
 @unique
 class DataType(Enum):
 	String = 1
